aboutsummaryrefslogtreecommitdiffstats
path: root/include/linux/mtd/nand.h
diff options
context:
space:
mode:
authorBoris Brezillon <boris.brezillon@free-electrons.com>2017-01-07 15:15:57 +0100
committerBoris Brezillon <boris.brezillon@free-electrons.com>2017-03-08 23:21:17 +0100
commit8cfb9ab68f90703d419870fce7ac21ac401399f2 (patch)
tree4bb50f82b6a4337c1056abcb2b89522d958dcc69 /include/linux/mtd/nand.h
parentmtd: nand: Rename nand_get_flash_type() into nand_detect() (diff)
downloadlinux-dev-8cfb9ab68f90703d419870fce7ac21ac401399f2.tar.xz
linux-dev-8cfb9ab68f90703d419870fce7ac21ac401399f2.zip
mtd: nand: Rename the nand_manufacturers struct
Drop the 's' at the end of nand_manufacturers since the struct is actually describing a single manufacturer, not a manufacturer table. Signed-off-by: Boris Brezillon <boris.brezillon@free-electrons.com>
Diffstat (limited to '')
-rw-r--r--include/linux/mtd/nand.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/linux/mtd/nand.h b/include/linux/mtd/nand.h
index e2c11351b1bd..9c679e8bde42 100644
--- a/include/linux/mtd/nand.h
+++ b/include/linux/mtd/nand.h
@@ -1062,17 +1062,17 @@ struct nand_flash_dev {
};
/**
* struct nand_manufacturers - NAND Flash Manufacturer ID Structure
* @name: Manufacturer name
* @id: manufacturer ID code of device.
*/
-struct nand_manufacturers {
+struct nand_manufacturer {
int id;
char *name;
};
extern struct nand_flash_dev nand_flash_ids[];
-extern struct nand_manufacturers nand_manuf_ids[];
+extern struct nand_manufacturer nand_manuf_ids[];
int nand_default_bbt(struct mtd_info *mtd);
int nand_markbad_bbt(struct mtd_info *mtd, loff_t offs);
@@ -1062,17 +1062,17 @@ struct nand_flash_dev {
};
/**
- * struct nand_manufacturers - NAND Flash Manufacturer ID Structure
+ * struct nand_manufacturer - NAND Flash Manufacturer structure
* @name: Manufacturer name
* @id: manufacturer ID code of device.